@@ -10,13 +10,16 @@ from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
 
 import time
-from random import randint
 import logging
+import contextlib
+
 try:
     import unittest2 as unittest
 except ImportError:  # Python 2.7
     import unittest
 
+from random import randint
+
 from . import t
 from .. import Server, log, exc
 
@@ -25,10 +28,36 @@ logger = logging.getLogger(__name__)
 TEST_SESSION_PREFIX = 'tmuxp_'
 
 
+def get_test_session_name(server, prefix='tmuxp_'):
+    while True:
+        session_name = prefix + str(randint(0, 9999999))
+        if not t.has_session(session_name):
+            break
+    return session_name
+
+
+@contextlib.contextmanager
+def temp_session(server, session_name=None):
+    if not session_name:
+        session_name = get_test_session_name(server)
+
+    session = server.new_session(session_name)
+    try:
+        yield session
+    finally:
+        if server.has_session(session_name):
+            session.kill_session()
+    return
+
+
 class TestCase(unittest.TestCase):
 
     """Base TestClass so we don't have to try: unittest2 every module. """
 
+    @classmethod
+    def setUpClass(cls):
+        super(TestCase, cls).setUpClass()  # for python 2.6 unittest2
+
 
 class TmuxTestCase(TestCase):
 
@@ -41,6 +70,7 @@ class TmuxTestCase(TestCase):
 
     def setUp(self):
         """Run bootstrap if :attr:`~.session` is not set."""
+
         if not self.TEST_SESSION_NAME or not self.session:
             self.bootstrap()
 
@@ -75,10 +105,7 @@ class TmuxTestCase(TestCase):
             )
         ]
 
-        while True:
-            TEST_SESSION_NAME = TEST_SESSION_PREFIX + str(randint(0, 9999999))
-            if not t.has_session(TEST_SESSION_NAME):
-                break
+        TEST_SESSION_NAME = get_test_session_name(server=t)
 
         try:
             session = t.new_session(
@@ -95,7 +122,7 @@ class TmuxTestCase(TestCase):
             t.switch_client(session.get('session_id'))
             pass
         except exc.TmuxpException as e:
-            #t.attach_session(session.get('session_id'))
+            # t.attach_session(session.get('session_id'))
             pass
 
         for old_test_session in old_test_sessions:
@@ -108,4 +135,5 @@ class TmuxTestCase(TestCase):
         assert TEST_SESSION_NAME != 'tmuxp'
 
         self.TEST_SESSION_NAME = TEST_SESSION_NAME
+        self.server = t
         self.session = session
